# pyspcbridge
## Introduction
Python library for interacting with the SPC Bridge REST/Websocket API. The library is especially designed for the SPC Bridge integration in Home Assistant (HA).

## Prerequisites
- Vanderbilt SPC panel, firmware version >= 3.8.5
- [SPC Bridge Generic Lite](https://www.lundix.se/spc-bridge-generic-lite/) or [SPC Bridge Generic](https://www.lundix.se/spc-bridge-generic/) from Lundix IT. **Please note!** The software module SPC Web Gateway isn't supported.

## Installation
This library is autmatically installed during installation of the SPC Bridge component (spcbridge) in Home Assistant.
